import enum


class DetailedState(enum.IntEnum):
    DISABLEDSTATE = 1
    ENABLEDSTATE = 2
    FAULTSTATE = 3
    OFFLINESTATE = 4
    STANDBYSTATE = 5
    NOTREADINGSTATE = 6
    CONFIGURINGSTATE = 7
    MANUALREADINGSTATE = 8
    READINGBUFFERSTATE = 9
    SETDURATIONREADINGSTATE = 10


class Units(enum.IntEnum):
    CURRENT = 1
    CHARGE = 2



# This file is part of ts_idl.
#
# Developed for Vera Rubin Observatory.
# This product includes software developed by the LSST Project
# (https://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License

__all__ = ["ChillerStatus", "PumpStatusFlag", "AlarmStatusFlag", "WarningStatusFlag"]

import enum


class ChillerStatus(enum.IntEnum):
    STANDBY = 1
    RUNNING = 2


class PumpStatusFlag(enum.IntEnum):
    PUMPOFF = 1
    PUMPON = 2


class AlarmStatusFlag(enum.IntEnum):
    NOALARM = 1
    ALARMPRESENT = 2


class WarningStatusFlag(enum.IntEnum):
    NOWARNING = 1
    WARNINGPRESENT = 2



# This file is part of ts_idl.
#
# Developed for Vera Rubin Observatory.
# This product includes software developed by the LSST Project
# (https://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License

__all__ = ["EnabledState", "Louver", "MotionState"]

import enum


class EnabledState(enum.IntEnum):
    """Drive enabled state."""

    DISABLED = 1
    ENABLED = 2
    FAULT = 3


class Louver(enum.IntEnum):
    """Louver name and associated array index."""

    A1 = 0
    B1 = 1
    A2 = 2
    B2 = 3
    B3 = 4
    N1 = 5
    M1 = 6
    N2 = 7
    M2 = 8
    M3 = 9
    C1 = 10
    C2 = 11
    C3 = 12
    L1 = 13
    L2 = 14
    L3 = 15
    E1 = 16
    D2 = 17
    E2 = 18
    D3 = 19
    E3 = 20
    I1 = 21
    H1 = 22
    I2 = 23
    H2 = 24
    I3 = 25
    H3 = 26
    F1 = 27
    G1 = 28
    F2 = 29
    G2 = 30
    F3 = 31
    G3 = 32
    D1 = 33


class MotionState(enum.IntEnum):
    """Motion state."""

    FAULT = 0
    CLOSED = 1
    CRAWLING = 2
    MOVING = 3
    OPEN = 4
    PARKED = 5
    PARKING = 6
    STOPPED = 7
    STOPPING = 8
    STOPPING_BRAKING = 9
    STOPPED_BRAKED = 10



# This file is part of ts_idl.
#
# Developed for the LSST Telescope & Site.
# This product includes software developed by the LSST Project
# (https://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License

__all__ = ["DetailedState", "HardpointActuatorMotionStates"]

import enum


class DetailedState(enum.IntEnum):
    DISABLED = 1
    FAULT = 2
    OFFLINE = 3
    STANDBY = 4
    PARKED = 5
    RAISING = 6
    ACTIVE = 7
    LOWERING = 8
    PARKEDENGINEERING = 9
    RAISINGENGINEERING = 10
    ACTIVEENGINEERING = 11
    LOWERINGENGINEERING = 12
    LOWERINGFAULT = 13
    PROFILEHARDPOINTCORRECTIONS = 14


class BumpTest(enum.IntEnum):
    NOTTESTED = 1
    TESTINGPOSITIVE = 2
    TESTINGPOSITIVEWAIT = 3
    TESTINGNEGATIVE = 4
    TESTINGNEGATIVEWAIT = 5
    PASSED = 6
    FAILED = 7


class HardpointActuatorMotionStates(enum.IntEnum):
    STANDBY = 0
    CHASING = 1
    STEPPING = 2
    QUICKPOSITIONING = 3
    FINEPOSITIONING = 4



import sys
import os
import setuptools

import pathlib
import glob

install_requires = []
tests_require = []
dev_requires = install_requires + tests_require + ["documenteer[pipelines]"]
tools_path = pathlib.Path(setuptools.__path__[0])
base_prefix = pathlib.Path(sys.base_prefix)
data_files_path = tools_path.relative_to(base_prefix).parents[1]
idl_files = glob.glob("idl/*.idl")

scm_version_template = """# Generated by setuptools_scm
__all__ = ["__version__"]

__version__ = "{version}"
"""


def local_scheme(version):
    sal_version = (
        os.environ.get("TS_SAL_VERSION", "0")
        .strip("v")
        .replace("pre", "")
        .split("_")[0]
    )
    xml_version = os.environ.get("TS_XML_VERSION", "0").strip("v")

    hash = [f"{int(v):02}" for v in f"{xml_version}.{sal_version}".split(".")]
    hash_str = ""
    for h in hash:
        hash_str += h
    return hash_str


setuptools.setup(
    name="ts_idl",
    description="Contains helper functions for the generated idl library by ts_sal.",
    # install_requires=install_requires,
    package_dir={"": "python"},
    use_scm_version={
        "write_to": "python/lsst/ts/idl/version.py",
        "write_to_template": scm_version_template,
        "local_scheme": local_scheme,
    },
    packages=setuptools.find_namespace_packages(where="python"),
    data_files=[(os.path.join(data_files_path, "idl"), idl_files)],
    include_package_data=True,
    # scripts=[],
    # tests_require=tests_require,
    extras_require={"dev": dev_requires},
    license="GPL",
    project_url={
        "Bug Tracker": "https://jira.lsstcorp.org/secure/Dashboard.jspa",
        "Source Code": "https://github.com/lsst-ts/ts_idl",
    },
)
